@@ -15,7 +15,7 @@ SubstitutionMatrix::SubstitutionMatrix(const double_matrix_t& matrix, const toke
     this->token_map_ = index;
 }
 
-double SubstitutionMatrix::forward(const char &from, const char &to) {
+double SubstitutionMatrix::forward(const char& from, const char& to) const {
     /**
      * Retrieve the substitution score for two input characters.
      *
@@ -23,8 +23,8 @@ double SubstitutionMatrix::forward(const char &from, const char &to) {
      * @param to: the second character in the substitution
      * @return the substitution score between two characters
      */
-    const auto& from_idx = this->token_map_[from];
-    const auto& to_idx = this->token_map_[to];
+    const auto& from_idx = this->token_map_.at(from);
+    const auto& to_idx = this->token_map_.at(to);
 
     return this->scoring_matrix_[from_idx][to_idx];
 }
